==> nextcloud-28.0.9.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ar.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "لقد قمت بتوليد الأكواد الاحتياطية للدخول المُثنّى لحسابك",
    "Second-factor backup codes" : "الأكواد الاحتياطية للعامل الثاني في الدخول المُثنّى",
    "Generate backup codes" : "توليد رموز الاسترجاع الاحتياطية",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "لقد قمت بتمكين التحقّق المثنى من الهوية لكنك لم تقم بتوليد الأكواد الاحتياطية بعد. ستحتاج هذه الأكواد لاسترجاع حق الدخول لحسابك إذا ما ضاع عاملك الثاني في الدخول.",
    "Backup code" : "الرمز الاحتياطي",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "Two factor backup codes" : "الأكواد الاحتياطية للدّخول المُثنّى",
    "A two-factor auth backup codes provider" : "مُوفّر الأكواد الاحتياطية للتحقّق المُثنّى من الهويّة",
    "Backup codes have been generated. {used} of {total} codes have been used." : "تمّ توليد الأكواد الاحتياطية. {used} من {total} تمّ استخدامها.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "هذه هي الرموز الاحتياطية الخاصة بك. يرجى حفظها و/أو طباعتها لأنك لن تتمكن من قراءة الرموز لاحقًا.",
    "Save backup codes" : "الإحتفاظ بالرموز الإحتياطية",
    "Print backup codes" : "طباعة الرموز الإحتياطية",
    "Regenerate backup codes" : "إعادة توليد رموز الإسترجاع الإحتياطية",
    "If you regenerate backup codes, you automatically invalidate old codes." : "عندما تقوم بتوليد أكواد احتياطية جديدة، فإن الأكواد القديمة تفقد صلاحيتها تلقائيّتاً.",
    "An error occurred while generating your backup codes" : "حدث خطأ عند توليد أكوادك الاحتياطية",
    "{name} backup codes" : "{name} أكواد احتياطية",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "استخدم واحداً من الأكواد الاحتياطية التي سبق و أن خزنتها عند تجهيز إعدادات التحقّق المُثنّى من الهويّة.",
    "Submit" : "إرسال ",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "هذه هي الأكواد الاحتياطية. رجاءً إحفظها أو إطبعها حيث أنك لن تستطيع قراءتها مجدّداً في المستقبل"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ar.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "لقد قمت بتوليد الأكواد الاحتياطية للدخول مع التحقق ثنائي العوامل لحسابك",
    "Second-factor backup codes" : "الأكواد الاحتياطية للعامل الثاني في الدخول مع التحقق ثنائي العوامل من الهوية",
    "Generate backup codes" : "توليد رموز الاسترجاع الاحتياطية",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "لقد قمت بتمكين التحقّق المثنى من الهوية لكنك لم تقم بتوليد الأكواد الاحتياطية بعد. ستحتاج هذه الأكواد لاسترجاع حق الدخول لحسابك إذا ما ضاع عاملك الثاني في الدخول.",
    "Backup code" : "الرمز الاحتياطي",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "Two factor backup codes" : "الأكواد الاحتياطية للتحقق ثنائي العوامل",
    "A two-factor auth backup codes provider" : "مزوّد الأكواد الاحتياطية للتحقق ثنائي العوامل من الهويّة",
    "Backup codes have been generated. {used} of {total} codes have been used." : "تمّ توليد الأكواد الاحتياطية. {used} من {total} تمّ استخدامها.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "هذه هي الرموز الاحتياطية الخاصة بك. يرجى حفظها و/أو طباعتها لأنك لن تتمكن من قراءة الرموز لاحقًا.",
    "Save backup codes" : "الإحتفاظ بالرموز الإحتياطية",
    "Print backup codes" : "طباعة الرموز الإحتياطية",
    "Regenerate backup codes" : "إعادة توليد رموز الإسترجاع الإحتياطية",
    "If you regenerate backup codes, you automatically invalidate old codes." : "عندما تقوم بتوليد أكواد احتياطية جديدة، فإن الأكواد القديمة تفقد صلاحيتها تلقائيّتاً.",
    "An error occurred while generating your backup codes" : "حدث خطأ عند توليد أكوادك الاحتياطية",
    "{name} backup codes" : "{name} أكواد احتياطية",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "استخدم واحداً من الأكواد الاحتياطية التي سبق و أن خزنتها عند تجهيز إعدادات التحقق ثنائي العوامل من الهويّة.",
    "Submit" : "إرسال ",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "هذه هي الأكواد الاحتياطية. رجاءً إحفظها أو إطبعها حيث أنك لن تستطيع قراءتها مجدّداً في المستقبل"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
